Data from Nanonis instruments¶
The reader supports .dat (spectroscopy) and .sxm (scan image) files written by the
Nanonis SPM control software of
SPECS Surface Nano Analysis GmbH. The .dat files are converted into
NXsts,
while .sxm files are converted into
NXstm
or NXafm,
depending on the experiment_technique given in the ELN file.
Both file formats are read with the vendored
nanonispy package in
src/pynxtools_spm/parsers/
(nanonis_dat.py with the class DatGenericNanonis, and nanonis_sxm.py with the class
SxmGenericNanonis).
Supported formats and versions¶
The version refers to the generation of the Nanonis SPM control software (the generic
version), not to the :NANONIS_VERSION: entry in the file header.
| Technique | Extension | Software | Tested versions | Formatter | Default config |
|---|---|---|---|---|---|
STS |
.dat |
Nanonis SPM control software | Generic 5, Generic 5e | NanonisDatSTS |
configs/nanonis/nanonis_dat_generic_sts.json |
STM |
.sxm |
Nanonis SPM control software | Generic 5, Generic 5e | NanonisSxmSTM |
configs/nanonis/nanonis_sxm_generic_stm.json |
AFM |
.sxm |
Nanonis SPM control software | Generic 4 | NanonisSxmAFM |
configs/nanonis/nanonis_sxm_generic_afm.json |
Files written by neighboring versions usually work as well, but may need an adapted config file. If no config file is passed on the command line, the default config shipped with the package is used.
.dat data (STS)¶
Download and try with the STS example files, or visit the GitHub folder.
pynx convert --nxdl NXsts --reader spm --output output.nxs eln_data.yaml Bias-Spectroscopy00015_20230420.dat config.json
.sxm data (STM)¶
Download and try with the STM example files, or visit the GitHub folder.
pynx convert --nxdl NXstm --reader spm --output output.nxs eln_data.yaml Au_mica_2023_Y_A_diPAMY_195.sxm config.json
.sxm data (AFM)¶
Download and try with the AFM example files, or visit the GitHub folder.
pynx convert --nxdl NXafm --reader spm --output output.nxs eln_data.yaml A151216.123306-02602.sxm config.json