Standalone Usages¶
pynxtools-spm is a tool for converting content from a raw data file and user provided data to the NeXus file according to the NeXus application definitions for SPM techniques.
One can use NOMAD (see how to upload in NOMAD documentation) research data management system (RMD) to upload the raw data files or command in terminal (needs pynxtools-spm installed in your local Python environment, see installation guide) to convert the raw data files into NeXus file.
For the formats, versions, and default config files of each vendor, see the reference pages Nanonis, Omicron, and Bruker.
Convert Data¶
After installing pynxtools-spm package, one can use the command line interface (CLI) to convert the raw data files into NeXus file. (see all available options by pynx convert --help).
To convert the raw data files from various techniques, use a command similar to the following -
1. Command to convert a STS raw data file into NeXus file
$ pynx convert --nxdl NXsts --reader spm --output output.nxs eln_data.yaml nanonis_sts_file.dat config.json
2. Command to convert a STM raw data file into NeXus file
$ pynx convert --nxdl NXstm --reader spm --output output.nxs eln_data.yaml nanonis_stm_file.sxm config.json
Download and try with STM example files or visit the GitHub folder.
3. Command to convert an Omicron STM raw data file (.sm4) into NeXus file
Download and try with Omicron STM example files or visit the GitHub folder. This example uses the default config shipped with the package; pass your own config.json as a further input file to override it.
4. Command to convert a Nanonis AFM raw data file (.sxm, Nanonis generic version 4) into NeXus file
$ pynx convert --nxdl NXafm --reader spm --output output.nxs eln_data.yaml nanonis_afm_file.sxm config.json
Download and try with AFM example files or visit the GitHub folder.
5. Command to convert a Bruker AFM raw data file (.FLT, written by SPMLab version 1.00) into NeXus file
$ pynx convert --nxdl NXafm --reader spm --output output.nxs eln_data.yaml bruker_afm_file.FLT config.json
Download and try with Bruker AFM example files or visit the GitHub folder.
Note
A Bruker SPMLab FLT file contains one channel of one scan direction (e.g. B3320_13_061726074638.SIG_TOPO_FRW.FLT is the forward height image), so each file is converted into its own NeXus file. The config file may be omitted, in which case the default config configs/bruker/bruker_flt_afm.json shipped with the package is used.